==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/classgko_1_1experimental_1_1distributed_1_1Vector.js <==
var classgko_1_1experimental_1_1distributed_1_1Vector =
[
    [ "add_scaled", "classgko_1_1experimental_1_1distributed_1_1Vector.html#acdafd131787d7c74478000ef8fdd82b8", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#aebbd31ab961257b915781c71a817ad9a", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ae0624723044ecb3c690a8daf79c5b762", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a0a7fc0c15ccc227e55a4adc0a244f61a", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a51e492ab5714013e8d9d3041bdf67143", null ],
    [ "compute_absolute", "classgko_1_1experimental_1_1distributed_1_1Vector.html#aa3de1addef14239271e4f360c1f046fb", null ],
    [ "compute_absolute_inplace", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7c24911b281d56382a2c280e2cb8019e", null ],
    [ "compute_conj_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a72ebeb082d05afea0fb30cfc0aaf3b30", null ],
    [ "compute_conj_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#afb34c41d7cc90868903aed98a3ff74f9", null ],
    [ "compute_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a81adfd6cfe1c585d60d65d95842bcf6a", null ],
    [ "compute_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#aaf7c602e9ef27c7d74a7735286b9ec90", null ],
    [ "compute_mean", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a0b682993b33f1686d6b81477d2f05a5e", null ],
    [ "compute_mean", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a90beecf68243906d251ac4fe148efd39", null ],
    [ "compute_norm1", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a95f68c957368afb25de478336dd3d615", null ],
    [ "compute_norm1", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ae49673363b8630674a5a2ce3fc649cc5", null ],
    [ "compute_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a1703cac44dc1591cafdd0a576cd55dbd", null ],
    [ "compute_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a5e8478fa78a9a9de4ee3a641857416c0", null ],
    [ "compute_squared_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7e9df98ba640deae6e9c3a73aff8074d", null ],
    [ "compute_squared_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a2ee403e1957707f02e1ae4bcfa818ec3", null ],
    [ "create_real_view", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a2c9bbab2a7cacb50dc65b76f75bce8db", null ],
    [ "create_real_view", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a43b4d0ff148a499ff2ea1ab692ccac93", null ],
    [ "fill", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a4a172e7b6b6088918e0c7f8070d43204", null ],
    [ "get_const_local_values", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a6f182db5f86018c07d6dc820c5302ce9", null ],
    [ "get_imag", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ab628f642dc2c64d0951b7eb731af464f", null ],
    [ "get_imag", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a9dbe5e69ef085b1a906543e62f1d4702", null ],
    [ "get_local_values", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a53719c22da01da00f61703285e4992eb", null ],
    [ "get_local_vector", "classgko_1_1experimental_1_1distributed_1_1Vector.html#adcb6f24d0faead09c7cef64e8efff86f", null ],
    [ "get_real", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a3ecafb045e29392b864cae5808e950b9", null ],
    [ "get_real", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7dc76840ffc5b10a41ef0d835fb5ecf3", null ],
    [ "inv_scale", "classgko_1_1experimental_1_1distributed_1_1Vector.html#abda3edba7d097804468a7bfddd38e70f", null ],
    [ "make_complex", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a93cd0c30e4c8493e9022d5542d2aee57", null ],
    [ "make_complex", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a2b5f3cf497e1f2d91b184ce4b8193343", null ],
    [ "read_distributed", "classgko_1_1experimental_1_1distributed_1_1Vector.html#adc91ab266a69a9fb6b513a2e31323eac", null ],
    [ "read_distributed", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a287880ccd4ad788623d3249589b2dc7f", null ],
    [ "scale", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ad5e5752219717ff7360e48b794f86b3e", null ],
    [ "sub_scaled", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7ff7ccd5ebf9042bf7840767032551f5", null ]
];

==> ginkgo-hpc-docs-1.11.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/classgko_1_1experimental_1_1distributed_1_1Vector.js <==
var classgko_1_1experimental_1_1distributed_1_1Vector =
[
    [ "add_scaled", "classgko_1_1experimental_1_1distributed_1_1Vector.html#acdafd131787d7c74478000ef8fdd82b8", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#aebbd31ab961257b915781c71a817ad9a", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ae0624723044ecb3c690a8daf79c5b762", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a0a7fc0c15ccc227e55a4adc0a244f61a", null ],
    [ "at_local", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a51e492ab5714013e8d9d3041bdf67143", null ],
    [ "compute_absolute", "classgko_1_1experimental_1_1distributed_1_1Vector.html#aa3de1addef14239271e4f360c1f046fb", null ],
    [ "compute_absolute_inplace", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7c24911b281d56382a2c280e2cb8019e", null ],
    [ "compute_conj_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a72ebeb082d05afea0fb30cfc0aaf3b30", null ],
    [ "compute_conj_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#afb34c41d7cc90868903aed98a3ff74f9", null ],
    [ "compute_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a81adfd6cfe1c585d60d65d95842bcf6a", null ],
    [ "compute_dot", "classgko_1_1experimental_1_1distributed_1_1Vector.html#aaf7c602e9ef27c7d74a7735286b9ec90", null ],
    [ "compute_mean", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a0b682993b33f1686d6b81477d2f05a5e", null ],
    [ "compute_mean", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a90beecf68243906d251ac4fe148efd39", null ],
    [ "compute_norm1", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a95f68c957368afb25de478336dd3d615", null ],
    [ "compute_norm1", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ae49673363b8630674a5a2ce3fc649cc5", null ],
    [ "compute_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a1703cac44dc1591cafdd0a576cd55dbd", null ],
    [ "compute_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a5e8478fa78a9a9de4ee3a641857416c0", null ],
    [ "compute_squared_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7e9df98ba640deae6e9c3a73aff8074d", null ],
    [ "compute_squared_norm2", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a2ee403e1957707f02e1ae4bcfa818ec3", null ],
    [ "create_real_view", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a2c9bbab2a7cacb50dc65b76f75bce8db", null ],
    [ "create_real_view", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a43b4d0ff148a499ff2ea1ab692ccac93", null ],
    [ "create_submatrix", "classgko_1_1experimental_1_1distributed_1_1Vector.html#aac78e04ed1fadd45b82fc627c97e8110", null ],
    [ "fill", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a4a172e7b6b6088918e0c7f8070d43204", null ],
    [ "get_const_local_values", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a6f182db5f86018c07d6dc820c5302ce9", null ],
    [ "get_imag", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ab628f642dc2c64d0951b7eb731af464f", null ],
    [ "get_imag", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a9dbe5e69ef085b1a906543e62f1d4702", null ],
    [ "get_local_values", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a53719c22da01da00f61703285e4992eb", null ],
    [ "get_local_vector", "classgko_1_1experimental_1_1distributed_1_1Vector.html#adcb6f24d0faead09c7cef64e8efff86f", null ],
    [ "get_real", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a3ecafb045e29392b864cae5808e950b9", null ],
    [ "get_real", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7dc76840ffc5b10a41ef0d835fb5ecf3", null ],
    [ "inv_scale", "classgko_1_1experimental_1_1distributed_1_1Vector.html#abda3edba7d097804468a7bfddd38e70f", null ],
    [ "make_complex", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a93cd0c30e4c8493e9022d5542d2aee57", null ],
    [ "make_complex", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a2b5f3cf497e1f2d91b184ce4b8193343", null ],
    [ "read_distributed", "classgko_1_1experimental_1_1distributed_1_1Vector.html#adc91ab266a69a9fb6b513a2e31323eac", null ],
    [ "read_distributed", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a287880ccd4ad788623d3249589b2dc7f", null ],
    [ "scale", "classgko_1_1experimental_1_1distributed_1_1Vector.html#ad5e5752219717ff7360e48b794f86b3e", null ],
    [ "sub_scaled", "classgko_1_1experimental_1_1distributed_1_1Vector.html#a7ff7ccd5ebf9042bf7840767032551f5", null ]
];
